%% Dobbs et al. 1971, Figure 2A: response of cardiac output and 
%   arterial pressure to volume infusion in normal dogs.
%   Note that taking the pressures from the figure resulted in 
%   an increase of only 11 mmHg from 115 to 126 mmHg. The paper
%   reports that the pressures should increase from 120.5 to 137.2 mmHg.
%   To make the data match the text, the values have been adjusted.
td1 = [-60    0     10    22     35    50    70    90   120];
Pd1 = [120   115   128   129    130   131   131   129   128]; % 10-minute time point modified to match paper
Ud1 = [0.523 0.644 1.42  2.23  5.17  5.59  5.08  4.65  4.14];  
Fd1 = [1500  1500  3010  2690  2330  2010  1930  1870  1810];
 
%% Dobbs et al. 1971, Figure 2B: response of cardiac output and 
%   arterial pressure to volume infusion in areflexic dogs.
td2 = [-60      0    5     10    30   60];
Pd2 = [100     92   189   200   138   90];  % 
Ud2 = [0.257 0.332  2.5  2.22 0.866 0.465]; 
Fd2 = [1500  1490  3450  2900  2180  1400];

%% Prather et al. 1969: response to an increase in volume for normal dog
td3 = [-20   0   5     25    45    65    85   105   130];
Vd3 = [1.0 1.0 1.45 1.385 1.322 1.257 1.189 1.177 1.162]*1363.6;

%% Quail et al. hemorrhage
PBRd = [0 5 10 15 20 25 30 35];
MAPd = [83.3   82    81   83   80.3   79.7   74.9   73.4]*100/83.3;
HRd  = [185   184   187   197   216   254   264   287]*75/185;
PHId = [2.24  2.37  2.64  3.05  3.19  4.74  8.58  10.3]./12.5;


%%
% Load initial conditions and initializing parameters
load par
load x0
par1 = par(1:9);
par2 = par(10:12);

alpha1  = par1(1);
alpha2  = par1(2);
alpha3  = par1(3);
alpha4  = par1(4);
tau_AR  = par1(5);
tau_R   = par1(6);
tau_A2  = par1(7);
Pra2    = par1(8);
Pra1    = par1(9);

F0      = par2(1);
F1      = par2(2);
Vv01    = par2(3);

% Systemic resistances and compliances
RA0 = 0.0661 / ((1+alpha2*0.25)*(1+alpha4*0.1857)) / ((tanh((1500-F0)/F1)+1)/2);
RV0 = 0.00033585;
CA0 = 0.63568 * ((1+alpha1*0.25)*(1+alpha3*0.1857));

% Aorta mechanics parameters
tau_ca  = 0.12/60;
CAo = 0.0070;
gamma_a = 0.40;
L = 30; % mm
D0 = 12;
V0 = (1e-3)*L*D0^2 / (2*pi);
% Baroreflex model parameters
tau_str = 251.525/60;
a       = 0.0651*60;
b       = 0.2004*60;
st0     = 0.4965;
f0      = 299.7511;
% SN tone parameters
fSN = 2.76;
% RA system
g       = 4*(100-Pra1-0.737*Pra2);
% Urine parameters
k1 = 0.125;
Ps_max = 126.4250;
Ps_min = 9.7788;
phi0   = 0.1928;
phi1   = 0.4813;
% Other parameters
Rout   = 0.0001;
RAo    = 0.0003;
tau_c1 = 2;
gamma1 = 0.4;
CV0 = (1287 - Vv01)*(1-gamma1)/1.55 * ((1+alpha1*0.25)*(1+alpha3*0.1857));
Qin01   = 0.5835;


%% Hemorrhage simulations
% The simulation is split into 3 runs: first 5 minutes of steady state with
% no hemorrhage, then 17.5 minutes of hemorrhage, then 12.5 minutes of
% recovery.
opts = odeset('MaxStep',0.001);
[t1,x1] = ode23tb(@dXdT2,[-5:0.5:0],x0,opts,par1,par2,0);
[t2,x2] = ode23tb(@dXdT2,[0:0.5:17.5],x1(end,:),opts,par1,par2,0 - 0.02*1363.6);
[t3,x3] = ode23tb(@dXdT2,[17.5:0.5:30],x2(end,:),opts,par1,par2,0);
t = [t1' t2' t3']';
x = [x1' x2' x3']';

phi_SN = x(:,10);
Pave   = x(:,12);
phi_R  = x(:,14);
H      = 75 + 100*(phi_SN - 0.25);

figure(1); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,Pave,'k-','linewidth',1.5);
plot([17.5 17.5],[75 105],'k--');
plot(PBRd/2,MAPd,'ko','Markersize',8,'linewidth',1.5,'MarkerFaceColor',[1 1 1]);
axis([0 30 75 105]);
set(ax1,'Fontsize',14);
ylabel('$\bar{P}$ (mmHg)','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);

figure(2); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,phi_SN,'k-','linewidth',1.5);
plot([17.5 17.5],[0 1],'k--');
axis([0 30 0 1]);
set(ax1,'Fontsize',14);
ylabel('$\phi_{SN}$','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);

figure(3); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,H,'k-','linewidth',1.5);
plot([17.5 17.5],[70 140],'k--');
plot(PBRd/2,HRd,'ko','Markersize',8,'linewidth',1.5,'MarkerFaceColor',[1 1 1]);
axis([0 30 70 140]);
set(ax1,'Fontsize',14);
ylabel('$H$ (beat sec$^{-1}$)','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);

figure(4); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,phi_R,'k-','linewidth',1.5);
plot([17.5 17.5],[0 1],'k--');
plot(PBRd/2,PHId,'ko','Markersize',8,'linewidth',1.5,'MarkerFaceColor',[1 1 1]);
axis([0 30 0 1]);
set(ax1,'Fontsize',14);
ylabel('$\phi_R$','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);

%% Doing the volume infusion experiments
% The simulation is split into 3 runs: first 10 minutes of steady state with
% no infusion, then 5 minutes of infusion, then 145 minutes of
% recovery.
[t1,x1] = ode23tb(@dXdT1,[-10:1:0],x0,opts,par1,par2,Qin01);
[t2,x2] = ode23tb(@dXdT1,[0:1:5],x1(end,:),opts,par1,par2,Qin01 + 634.09/5);
[t3,x3] = ode23tb(@dXdT1,[5:1:150],x2(end,:),opts,par1,par2,Qin01);
t = [t1' t2' t3']';
x = [x1' x2' x3']';

V_lv   = x(:,1);
V_Ao   = x(:,2);
V_A    = x(:,3);
V_V    = x(:,4);
Vsa    = x(:,5);
Ps     = x(:,7);
phi_SN = x(:,10);
Pave   = x(:,12);
Fave   = x(:,13);
phi_R  = x(:,14);
V = V_lv + V_Ao + V_A + V_V;
Qurine = max(0,min( k1*(Pave-Ps),10 ));

figure(5); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,Pave,'k-','linewidth',1.5); 
plot(td1,Pd1-15,'ko','Markersize',8,'linewidth',1.5,'MarkerFaceColor',[1 1 1]);
axis([-10 150 80 130]);
set(gca,'Fontsize',14);
ylabel('$P_A$ (mmHg)','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);

figure(6); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,Fave,'k-','linewidth',1.5); 
plot(td1,Fd1,'ko','Markersize',8,'linewidth',1.5,'MarkerFaceColor',[1 1 1]);
axis([-10 150 0 3800]);
set(gca,'Fontsize',14);
ylabel('$F$ (ml min$^{-1}$)','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);

figure(7); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,Qurine,'k-','linewidth',1.5); 
plot(td1,Ud1,'ko','Markersize',8,'linewidth',1.5,'MarkerFaceColor',[1 1 1]);
set(gca,'Xlim',[-10 150]);
set(gca,'Fontsize',14);
ylabel('$Q_{urine}$ (ml min$^{-1}$)','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);

figure(8); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,V,'k-','linewidth',1.5); 
plot(td3,Vd3,'ko','Markersize',8,'linewidth',1.5,'MarkerFaceColor',[1 1 1]);
axis([-10 150 1200 2200]);
set(gca,'Fontsize',14);
ylabel('Volume (ml)','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);

figure(9); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,phi_SN,'k-','linewidth',1.5); 
axis([-10 150 0 0.3]);
set(gca,'Fontsize',14);
ylabel('$\phi_{SN}$','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);

figure(10); clf; ax1 = axes('position',[0.15 0.15 0.78 0.78]); hold on; box on
plot(t,phi_R,'k-','linewidth',1.5); 
axis([-10 150 0 0.3]);
set(gca,'Fontsize',14);
ylabel('$\phi_R$','interpreter','latex','Fontsize',16);
xlabel('$t$ (min)','interpreter','latex','Fontsize',16);


